if __name__ == "__main__":
    import sys
    from itertools import combinations
    from pathlib import Path

    from spatialdata_io import macsima

    # get path from input argument
    path = Path(sys.argv[1])
    output = Path(sys.argv[2])
    assert path.exists(), f"Path {path} does not exist"
    output.mkdir(exist_ok=True)

    possible_options = [
        "3c",
        "ome",
        "vtk",
        "microns",
    ]
    all_options = [tuple()] + [item for r in range(1, len(possible_options)+1) for item in list(combinations(possible_options, r))]
    
    links = []
    for options in all_options:
        print(options)
        dataset_name = path.stem
        extra_name = '_' + '_'.join(options) if options else ''
        output_name = dataset_name + extra_name + '.zarr'
        url = 'https://dl01.irc.ugent.be/spatial/proteomics/macsima_liver/ome_test/' + output_name
        ngff_url = url + f'/images/{dataset_name + ".zarr" if "vtk" in options else dataset_name}'
        links.append(f'[{output_name}]({url}) [NGFF validator](https://ome.github.io/ome-ngff-validator/?source={ngff_url})')
        sdata = macsima(path, c_subset=3 if '3c' in options else 10, subset=1000, output_path=output / output_name, transformations='microns' in options,  write_ome='ome' in options, label_name=dataset_name + '.zarr' if 'vtk' in options else None)
        print(sdata)

    print('\n'.join(links))
